/**
	$Id: TabAction.java 6653 2014-12-09 11:56:20Z nicklas $

	Copyright (C) 2010 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.clients.web.extensions.tabcontrol;

import net.sf.basedb.clients.web.extensions.UnsafeScriptable;
import net.sf.basedb.core.Help;
import net.sf.basedb.util.extensions.Action;

/**
	Action that inserts a new tab in a tabcontrol. 

	@author Nicklas
	@since 2.17
	@base.modified $Date: 2014-12-09 12:56:20 +0100 (tis, 09 dec. 2014) $
*/
@UnsafeScriptable
public interface TabAction
	extends Action
{

	/**
		ID attribute of the main tab tag. You need to set
		this value to reference the tab in a javascript.
		@return The ID, or null
	*/
	public String getId();

	/**
		Class attribute of the main tab tag.
		@return Class attribute, or null to not add any class attribute
	*/
	public String getClazz();
	
	/**
		Extra CSS style attributes that will be added to the
		<code>style</code> attribute of the main tab tag.
		@return Style attributes, or null
	*/
	public String getStyle();
	
	/**
		Get the title of the tab. 
	*/
	public String getTitle();
	
	/**
		A tooltip that is shown as a yellow popup when the 
		user points the mouse at the tab.
		@return The tooltip or null to not display any tooltip
	*/
	public String getTooltip();

	/**
		The external id of a help text that the user can display
		to get more information about how to use the information
		in this tab. See {@link Help#getExternalId()}.
		
		@return The help id or null to not display any help
	*/
	public String getHelpId();

	/**
		If the tab should be visible or not.
	*/
	public boolean isVisible();
	
	/**
		Get the (HTML) contents of the tab.
	*/
	public String getContent();
	
	/**
		Get the tab index used to control focus order when tabbing. 
		Use -1 to disable.
		@since 3.2
	*/
	public int getTabIndex();

}
