/**
	$Id $

	Copyright (C) 2010 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.clients.web.plugins;

import java.util.ArrayList;
import java.util.List;

import net.sf.basedb.core.DataFileType;
import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.FileSetMember;
import net.sf.basedb.core.FileStoreEnabled;
import net.sf.basedb.core.Include;
import net.sf.basedb.core.Item;
import net.sf.basedb.core.ItemQuery;
import net.sf.basedb.core.Metadata.PropertyPath;
import net.sf.basedb.core.query.Hql;
import net.sf.basedb.core.query.Restrictions;
import net.sf.basedb.core.PermissionDeniedException;

/**	
	Data loader implementation that load the files in a file set
	in {@link FileStoreEnabled} items.
	
	@author Nicklas
	@version 2.16
	@base.modified $Date: 2015-04-21 08:26:57 +0200 (tis, 21 apr. 2015) $
*/
public class FileSetMemberLoader 
	implements DataLoader<FileStoreEnabled>
{

	private DataFileType fileType;
	private PropertyPath<FileSetMember, ?> propertyPath;
	private ItemQuery<FileSetMember> memberQuery;

	public FileSetMemberLoader()
	{
		this(null, null);
	}
	
	/**
		Load only members of the given file type and then use the given property path
		to load a specific property of the member.
		@param fileType The file type to load or null to load all members
		@param propertyPath The property to load or null to load the file item of the member.
			The property path must start on a {@link Item#FILESETMEMBER} item.
		@since 3.5
	*/
	public FileSetMemberLoader(DataFileType fileType, PropertyPath<FileSetMember, ?> propertyPath)
	{
		this.fileType = fileType;
		this.propertyPath = propertyPath;
		this.memberQuery = FileSetMember.getQuery(null);
		if (fileType != null)
		{
			memberQuery.restrict(
				Restrictions.eq(
					Hql.property("dataFileType"), 
					Hql.entity(fileType)
				));
		}
		memberQuery.setIncludes(Include.ALL);

	}
	
	@Override
	public Object getData(DbControl dc, ExportedProperty exportedProperty, FileStoreEnabled item) 
	{
		if (!item.hasFileSet()) return null;
		
		memberQuery.setEntityParameter("fileSet", item.getFileSet());
		List<FileSetMember> members = memberQuery.list(dc);

		List<Object> info = new ArrayList<Object>(members.size());
		for (FileSetMember member : members)
		{
			try
			{
				info.add(propertyPath == null ? member.getFile() : propertyPath.getValue(dc, member));
			}
			catch (PermissionDeniedException ex)
			{}
		}
		return info;
	}

}
