/**
	$Id: ItemQueryWrapper.java 6132 2012-09-14 10:29:16Z nicklas $

	Copyright (C) 2006 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.clients.web.plugins;

import net.sf.basedb.core.BasicItem;
import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.ItemQuery;
import net.sf.basedb.core.Metadata;
import net.sf.basedb.core.query.ResultIterator;

/**
	A query wrapper for {@link ItemQuery}:s.
	
	@author nicklas
	@version 2.2
	@base.modified $Date: 2012-09-14 12:29:16 +0200 (fre, 14 sep. 2012) $
*/
public class ItemQueryWrapper
	implements QueryWrapper<BasicItem>
{
	private final ItemQuery<BasicItem> query;
	
	/**
		Create a new query wrapper.
		@param query The query
		@since 2.15
	*/
	public ItemQueryWrapper(ItemQuery<BasicItem> query)
	{
		this.query = query;
	}
	
	/**
		Calls {@link ItemQuery#iterate(DbControl)}
	*/
	@Override
	public ResultIterator<BasicItem> iterate(DbControl dc)
	{
		return query.iterate(dc);
	}
	
	/**
		Calls {@link BasicItem#getId()}
	*/
	@Override
	public int getId(BasicItem item)
	{
		return item.getId();
	}
	
	/**
		Uses a {@link Metadata} object to get the value of the specified property.
	*/
	@SuppressWarnings("unchecked")
	@Override
	public Object getData(DbControl dc, ExportedProperty exportedProperty, BasicItem item)
	{
		return exportedProperty.propertyPath.getValue(dc, item);
	}
	
	
}
