/*
	$Id: CacheControlFilter.java 5900 2011-12-07 13:43:15Z nicklas $

	Copyright (C) 2011 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.clients.web.servlet;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletResponse;

import java.io.IOException;

/**
	This is a filter that sets the "Cache-Control" header
	in the http response. It can be useful in a development
	environment to, for example, disable caching of *.js
	and *.css files. See example in the web.xml file.

	@author Nicklas
	@since 3.1
	@base.modified $Date: 2011-12-07 14:43:15 +0100 (ons, 07 dec. 2011) $
*/
public final class CacheControlFilter
	implements Filter
{

	private String cacheControl = null;
	
	@Override
	public void init(FilterConfig config)
	{
		if (config.getInitParameter("cache-control") != null)
		{
			cacheControl = config.getInitParameter("cache-control");
		}
	}
	
	@Override
	public void destroy()
	{}
	
	@Override
	public void doFilter(ServletRequest request, ServletResponse response, FilterChain chain)
		throws IOException, ServletException
	{
		HttpServletResponse resp = (HttpServletResponse) response;
		resp.setHeader("Cache-Control", cacheControl);
		chain.doFilter(request, response);
	}
}
