/*
	$Id: AbstractResultList.java 6127 2012-09-14 07:28:35Z nicklas $

	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core;

import net.sf.basedb.core.query.ResultList;

import java.util.Collection;

/**
	This is a list of the result from a query. Objects returned from 
	this list are of a type derived from BasicItem. This class implements
	all operations in the <code>List</code> interface that modifies the 
	list. The implementation simply throws an 
	<code>UnsupportedOperationException</code>
	
	@author Samuel, Nicklas
	@version 2.0
	@base.modified $Date: 2012-09-14 09:28:35 +0200 (fre, 14 sep. 2012) $
*/
abstract class AbstractResultList<I>
	implements ResultList<I>
{

	private final long totalCount;

	AbstractResultList(long totalCount)
	{
		this.totalCount = totalCount;
	}

	/*
		From the QueryResult interface
		-------------------------------------------
	*/
	@Override
	public long getTotalCount()
	{
		return totalCount;
	}
	// -------------------------------------------

	/*
		From the List interface
		-------------------------------------------
	*/
	/**
		Not supported.
		@throws UnsupportedOperationException Always
	*/
	@Override
	public boolean add(I o)
	{
		throw new UnsupportedOperationException();
	}

	/**
		Not supported.
		@throws UnsupportedOperationException Always
	*/
	@Override
	public void add(int index, I element)
	{
		throw new UnsupportedOperationException();
	}

	/**
		Not supported.
		@throws UnsupportedOperationException Always
	*/
	@Override
	public boolean addAll(Collection<? extends I> c)
	{
		throw new UnsupportedOperationException();
	}
	
	/**
		Not supported.
		@throws UnsupportedOperationException Always
	*/
	@Override
	public boolean addAll(int index, Collection<? extends I> c)
	{
		throw new UnsupportedOperationException();
	}

	/**
		Not supported.
		@throws UnsupportedOperationException Always
	*/
	@Override
	public void clear()
	{
		throw new UnsupportedOperationException();
	}

	@Override
	public boolean containsAll(Collection<?> c)
	{
		for (Object o : c)
		{
			if (!contains(o)) return false;
		}
		return true;
	}

	/**
		Not supported.
		@throws UnsupportedOperationException Always
	*/
	@Override
	public I remove(int index)
	{
		throw new UnsupportedOperationException();
	}

	/**
		Not supported.
		@throws UnsupportedOperationException Always
	*/
	@Override
	public boolean remove(Object o)
	{
		throw new UnsupportedOperationException();
	}

	/**
		Not supported.
		@throws UnsupportedOperationException Always
	*/
	@Override
	public boolean removeAll(Collection<?> c)
	{
		throw new UnsupportedOperationException();
	}

	/**
		Not supported.
		@throws UnsupportedOperationException Always
	*/
	@Override
	public boolean retainAll(Collection<?> c)
	{
		throw new UnsupportedOperationException();
	}

	/**
		Not supported.
		@throws UnsupportedOperationException Always
	*/
	@Override
	public I set(int index, I element)
	{
		throw new UnsupportedOperationException();
	}
	// -------------------------------------------

}
