/*
	$Id: BooleanParameterType.java 6372 2013-12-06 10:52:11Z nicklas $

	Copyright (C) 2005 Johan Enell, Nicklas Nordborg
	Copyright (C) 2006 Johan Enell, Jari Häkkinen

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core;

import net.sf.basedb.core.data.BooleanParameterValueData;
import net.sf.basedb.util.Enumeration;

/**
	This class represent a parameter type that is a boolean.

	@author Nicklas
	@version 2.0
	@base.modified $Date: 2013-12-06 11:52:11 +0100 (fre, 06 dec. 2013) $
*/
public class BooleanParameterType
	extends ParameterType<Boolean>
{
	/**
		Create a new boolean parameter type, allowing null values.
	*/
	public BooleanParameterType()
	{
		this(null, false);
	}
	
	/**
		Create a new boolean parameter type.
	 	@param defaultValue Default value to use. Null is allowed.
		@param notNull FALSE if nulls values are allowed, TRUE otherwise
	*/
	public BooleanParameterType(Boolean defaultValue, boolean notNull)
	{
		super(Type.BOOLEAN, Boolean.class, defaultValue, notNull);
	}

	public BooleanParameterType(Boolean defaultValue, boolean notNull, int multiplicity, Enumeration<Boolean, String> items)
	{
		super(Type.BOOLEAN, Boolean.class, defaultValue, notNull, multiplicity, 0, 0, items, false);
	}

	/*
		From the Object class
		-------------------------------------------
	*/
	@Override
	public String toString()
	{
		return "BooleanParameterType";
	}
	// -------------------------------------------

	/*
		From the ParameterType class
		-------------------------------------------
	*/
	/**
		Always validate.
	*/
	@Override
	void validateValue(String name, Boolean value)
		throws InvalidDataException
	{}
	
	/**
		Create a new {@link BooleanParameterValueData} object.
	*/
	@Override
	BooleanParameterValueData newParameterValueData()
	{
		return new BooleanParameterValueData();
	}
	// -------------------------------------------


}
