/**
	$Id: LogUtil.java 6444 2014-04-09 12:21:20Z nicklas $

	Copyright (C) 2006 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core;

import java.sql.SQLException;

import org.slf4j.Logger;

/**
 	Utility class for LOG4J logging.

	@author nicklas
	@version 2.0
	@base.modified $Date: 2014-04-09 14:21:20 +0200 (ons, 09 apr. 2014) $
*/
public class LogUtil
{

	/**
	 	Log the chained exceptions of an SQLException. An SQLException is different 
	 	from other exceptions in that is uses {@link SQLException#getNextException()}
		instead of {@link Throwable#getCause()} to chain exceptions. This methods
		log the <code>getNextException</code> chain.
	 	<p>
	 	Note! This method doesn't log the <code>ex</code> exception. It only
	 	logs the chained exceptions. If there are more than 10 nested exception
	 	it only logs the first 10.
	 	
		@param logger The logger to use
		@param ex The SQL exception
	*/
	public static void logSQLExceptionChain(Logger logger, SQLException ex)
	{
		SQLException next = ex.getNextException();
		int i = 1;
		while (next != null && i < 10)
		{
			logger.error("Next exception #" + i, next);
			i++;
		}
	}
	
}
