/*
	$Id: Registered.java 7308 2017-03-13 08:15:46Z nicklas $

	Copyright (C) 2005 Jari Häkkinen, Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core;

import java.util.Date;

/**
	Items that implements this interface has their registration
	date stored in the database. Note to implementors!!! Do not
	forget that Date is a mutable class and that a copy must be made
	before returning the value to client applications.
	See {@link DateUtil#copy(Date)}
	
	@author Nicklas
	@version 2.10
	@base.modified $Date: 2017-03-13 09:15:46 +0100 (mån, 13 mars 2017) $
*/
public interface Registered
	extends Identifiable
{

	/**
		Get the date that the item was registered in the database.
		@return A date or null if this is not known
		@since 2.10
	*/
	public Date getEntryDate();

	/**
		Set the date the entry was registered in the database.
		Implementations should only allow this property to be
		set before the item is first stored in the database.
		The intention of this method is to facilitate export/import
		of data between server.
		@param entryDate A date or null to use today's date
		@since 3.11
	*/
	public void setEntryDate(Date entryDate);
	
}
