/*
	$Id: ReporterScore.java 7014 2015-11-12 08:43:25Z nicklas $

	Copyright (C) 2006 Nicklas Nordborg
	
	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/
	
	BASE is free software; you can redistribute it and/or modify it
	under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 3 of the License, or
	(at your option) any later version.
	
	BASE is distributed in the hope that it will be useful, but
	WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
	General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core;

import net.sf.basedb.core.data.ReporterData;
import net.sf.basedb.core.data.ReporterListScoreData;
import net.sf.basedb.core.query.Hql;
import net.sf.basedb.core.query.PermissionRestriction;
import net.sf.basedb.core.query.Restrictions;


/**
	Get information about the reporters and their score in a reporter list.

	@author Nicklas
	@version 2.0
	@see ReporterList
	@base.modified $Date: 2015-11-12 09:43:25 +0100 (tors, 12 nov. 2015) $
*/
public class ReporterScore
{

	/**
		Get a query object configured to retrieve reporters.
		@return A {@link DataQuery} object
	*/
	public static ReporterScoreQuery getQuery(ReporterList reporterList)
	{
		ReporterScoreQuery query = new ReporterScoreQuery();
		// We allow reporters without READ permission unless it has been explicitely DENIED
		query.restrictPermanent(new PermissionRestriction(Permission.DENIED, Item.REPORTER));
		// Join reporters with prefetch to avoid additional selects for each reporter
		query.joinPermanent(Hql.innerJoin(null, "reporter", Item.REPORTER.getAlias(), true));
		query.restrictPermanent(
			Restrictions.eq(
				Hql.property("reporterList"), 
				Hql.entity(reporterList)
			)
		);
		return query;
	}

	private final ReporterListScoreData data;
	
	ReporterScore(ReporterListScoreData data)
	{
		this.data = data;
	}
	
	ReporterListScoreData getData()
	{
		return data;
	}
	
	/**
		Get the reporter. 
		@return A <code>ReporterData</code> object
	*/
	public ReporterData getReporter()
	{
		return data.getReporter();
	}
	
	/**
		Get the score for this reporter or null if no score has been set. To set the
		score use {@link ReporterList#addReporter(ReporterData, Float)}
		@return The score or null
	*/
	public Float getScore()
	{
		return data.getScore();
	}
	
}
