/*
	$Id: BioAssayData.java 7150 2016-04-27 06:38:21Z nicklas $
	
	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg, Gregory Vincic
	
	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/
	
	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.
	
	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

import java.util.Set;
import java.util.HashSet;

import net.sf.basedb.core.data.annotations.AnnotationLink;

/**
	This class holds information about a bioassay.
	
	@author Nicklas
	@version 2.0
	@see net.sf.basedb.core.BioAssay
	@see <a href="../../../../../../html/developer/api/data_api.experiments.html">Developer documentation: Experiments and analysis</a>
	@base.modified $Date: 2016-04-27 08:38:21 +0200 (ons, 27 apr. 2016) $
	@hibernate.class table="`BioAssays`" lazy="true"
*/
public class BioAssayData
	extends BasicData
	implements NameableData, AnnotatableData
{
	public BioAssayData()
	{}

	/*
		From the NameableData interface
		-------------------------------------------
	*/	
	private String name;
	@Override
	public String getName()
	{
		return name;
	}

	@Override
	public void setName(String name)
	{
		this.name = name;
	}

	private String description;
	@Override
	public String getDescription()
	{
		return description;
	}

	@Override
	public void setDescription(String description)
	{
		this.description = description;
	}
	// -------------------------------------------
	/*
		From the AnnotatableData interface
		-------------------------------------------
	*/
	private AnnotationSetData annotationSet;
	/**
		@since 2.2
	*/
	@Override
	public AnnotationSetData getAnnotationSet()
	{
		return annotationSet;
	}
	/**
		@since 2.2
	*/
	@Override
	public void setAnnotationSet(AnnotationSetData annotationSet)
	{
		this.annotationSet = annotationSet;
	}
	private Set<AnnotationLink> links;
	@Override
	public Set<AnnotationLink> getAnnotations()
	{
		return links;
	}
	void setAnnotations(Set<AnnotationLink> links)
	{
		this.links = links;
	}
	// -------------------------------------------

	private BioAssaySetData bioAssaySet;
	/**
		Get the bioassayset this bioassay belongs to.
		@hibernate.many-to-one column="`bioassayset_id`" not-null="true" outer-join="false" update="false" unique-key="BioAssay_uniquecolumn"
	*/
	public BioAssaySetData getBioAssaySet()
	{
		return bioAssaySet;
	}
	public void setBioAssaySet(BioAssaySetData bioAssaySet)
	{
		this.bioAssaySet = bioAssaySet;
	}

	private DataCubeColumnData dataCubeColumn;
	/**
		Get the column this bioassay stores it's data in.
		@hibernate.many-to-one column="`datacubecolumn_id`" not-null="true" unique-key="BioAssay_uniquecolumn"
			outer-join="false" update="false" cascade="save-update"
	*/
	public DataCubeColumnData getDataCubeColumn()
	{
		return dataCubeColumn;
	}
	public void setDataCubeColumn(DataCubeColumnData dataCubeColumn)
	{
		this.dataCubeColumn = dataCubeColumn;
	}

	private int numSpots;
	/**
		The number of unique spots in this bioassay.
		@hibernate.property column="`spots`" type="int" not-null="true" update="false"
	*/
	public int getNumSpots()
	{
		return numSpots;
	}
	public void setNumSpots(int numSpots)
	{
		this.numSpots = numSpots;
	}
	private int numFileSpots;
	/**
		The number of unique spots in this bioassayset.
		@hibernate.property column="`file_spots`" type="int" not-null="true"
		@since 2.8
	*/
	public int getNumFileSpots()
	{
		return numFileSpots;
	}
	/**
		@since 2.8
	*/
	public void setNumFileSpots(int numFileSpots)
	{
		this.numFileSpots = numFileSpots;
	}

	private Set<BioAssayData> parents;
	/**
		Get a set that manages the parent bioassays the data in this bioassay 
		is based on.
		@hibernate.set table="`BioAssayParents`" lazy="true"
		@hibernate.collection-key column="`bioassay_id`"
		@hibernate.collection-many-to-many column="`parent_id`" class="net.sf.basedb.core.data.BioAssayData"
	*/
	public Set<BioAssayData> getParents()
	{
		if (parents == null) parents = new HashSet<BioAssayData>();
		return parents;
	}
	void setParents(Set<BioAssayData> parents)
	{
		this.parents = parents;
	}
	
	private Set<BioAssayData> children;
	/**
		This is the inverse end to {@link #getParents()}. 
		@hibernate.set table="`BioAssayParents`" lazy="true" inverse="true"
		@hibernate.collection-key column="`parent_id`"
		@hibernate.collection-many-to-many column="`bioassay_id`" class="net.sf.basedb.core.data.BioAssayData"
	*/
	Set<BioAssayData> getChildren()
	{		
		return children;
	}
	void setChildren(Set<BioAssayData> children)
	{
		this.children = children;
	}

	private Set<RawBioAssayData> rawParents;
	/**
		Get a set that manages the raw parent bioassays the data in this bioassay 
		is based on.
		@hibernate.set table="`BioAssayRawParents`" lazy="true"
		@hibernate.collection-key column="`bioassay_id`"
		@hibernate.collection-many-to-many column="`parent_id`" class="net.sf.basedb.core.data.RawBioAssayData"
	*/
	public Set<RawBioAssayData> getRawParents()
	{
		if (rawParents == null) rawParents = new HashSet<RawBioAssayData>();
		return rawParents;
	}
	void setRawParents(Set<RawBioAssayData> rawParents)
	{
		this.rawParents = rawParents;
	}

}
