/*
	$Id $

	Copyright (C) 2010 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

import java.util.Set;

/**
	This class holds information about a biomaterial plate type.

	@author Nicklas
	@since 2.16
	@see net.sf.basedb.core.BioPlateType
	@base.modified $Date: 2015-11-17 13:57:57 +0100 (tis, 17 nov. 2015) $
	@hibernate.class table="`BioPlateTypes`" lazy="false"
	@see <a href="../../../../../../html/developer/api/data_api.biomaterials.html">Developer documentation: Biomaterials LIMS</a>
*/
public class BioPlateTypeData
	extends BasicData
	implements NameableData, RemovableData
{

	public BioPlateTypeData()
	{}

	/*
		From the NameableData interface
		-------------------------------------------
	*/
	private String name;
	@Override
	public String getName()
	{
		return name;
	}
	@Override
	public void setName(String name)
	{
		this.name = name;
	}
	private String description;
	@Override
	public String getDescription()
	{
		return description;
	}
	@Override
	public void setDescription(String description)
	{
		this.description = description;
	}
	// -------------------------------------------
	/*
		From the RemovableData interface
		-------------------------------------------
	*/
	private Integer removedBy;
	@Override
	public Integer getRemovedBy()
	{
		return removedBy;
	}
	@Override
	public void setRemovedBy(Integer removedBy)
	{
		this.removedBy = removedBy;
	}
	// -------------------------------------------

	
	private Integer bioMaterialType;
	/**
		If set, plates using this type can only hold the specific biomaterial
		type (eg. samples, extracts or labeled extracts).
		@hibernate.property column="`biomaterial_type`" type="int" update="false"
	*/
	public Integer getBioMaterialType()
	{
		return bioMaterialType;
	}
	public void setBioMaterialType(Integer bioMaterialType)
	{
		this.bioMaterialType = bioMaterialType;
	}

	private ItemSubtypeData subtype;
	/**
		Get the subtype of biomaterials that can be placed on plates of this type.
		@hibernate.many-to-one column="`subtype_id`" not-null="false" outer-join="false"
		@since 3.0
	*/
	public ItemSubtypeData getItemSubtype()
	{
		return subtype;
	}
	public void setItemSubtype(ItemSubtypeData subtype)
	{
		this.subtype = subtype;
	}
	
	private ItemSubtypeData storageType;
	/**
		Get the subtype of storage location where plates of this type are usually stored.
		The storage type should be a subtype for hardware items.
		@hibernate.many-to-one column="`storagetype_id`" not-null="false" outer-join="false"
		@since 3.2
	*/
	public ItemSubtypeData getStorageType()
	{
		return storageType;
	}
	public void setStorageType(ItemSubtypeData storageType)
	{
		this.storageType = storageType;
	}

	
	private int lockMode;
	/**
		A flag indicating if plates with this type have locked wells or not.
		0 = not locked; 1 = locked-after-move; 2 = locked-after-add; 3=locked-after-create
		@hibernate.property column="`lock_mode`" type="int" not-null="true"
	*/
	public int getLockMode()
	{
		return lockMode;
	}
	public void setLockMode(int lockMode)
	{
		this.lockMode = lockMode;
	}
	
	private Set<BioPlateData> bioPlates;
	/**
		The bioplates that use this type. This is the inverse end.
		@see BioPlateData#getBioPlateType()
		@hibernate.set lazy="true" inverse="true"
		@hibernate.collection-key column="`bioplatetype_id`"
		@hibernate.collection-one-to-many class="net.sf.basedb.core.data.BioPlateData"
	*/
	Set<BioPlateData> getBioPlates()
	{
		return bioPlates;
	}
	void setBioPlates(Set<BioPlateData> bioPlates)
	{
		this.bioPlates = bioPlates;
	}

}
