/*
  $Id: ClientData.java 7405 2017-10-04 10:59:03Z nicklas $

	Copyright (C) 2005 Johan Enell, Jari Häkkinen, Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

  BASE is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 3
  of the License, or (at your option) any later version.

  BASE is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

import java.util.Date;
import java.util.Set;

/**
	This class holds information about a client.
 
	@author enell
	@version 2.0
	@see net.sf.basedb.core.Client
	@see <a href="../../../../../../html/developer/api/data_api.clients.html">Developer documentation: Client, session and settings</a>
	@hibernate.class table="`Clients`" lazy="false"
*/
public class ClientData
	extends CommonData
	implements RegisteredData
{
	public ClientData()
	{}
	
	/*
		From the RegisteredData interface
		-------------------------------------------
	*/
	private Date entryDate;
	@Override
	public Date getEntryDate()
	{
		return entryDate;
	}
	public void setEntryDate(Date entryDate)
	{
		this.entryDate = entryDate;
	}
	// -------------------------------------------
	
	/**
		The maximum length of the external ID that can be stored in the database.
		@see #setExternalId(String)
	*/
	public static final int MAX_EXTERNAL_ID_LENGTH = 255;
	private String externalId;
	/**
		Get the external id for this <code>Client</code> item.
		@hibernate.property column="`external_id`" type="string" length="255" not-null="true" unique="true"
	*/
	public String getExternalId()
	{
		return externalId;
	}
	public void setExternalId(String externalId)
	{
		this.externalId = externalId;
	}
	
	private boolean supportsDeviceVerification;
	/**
		A flag indicating if this client application supports device verification.
		@since 3.12
		@hibernate.property column="`supports_device_verification`" type="boolean" not-null="true"
	*/
	public boolean getSupportsDeviceVerification()
	{
		return supportsDeviceVerification;
	}
	public void setSupportsDeviceVerification(boolean supportsDeviceVerification)
	{
		this.supportsDeviceVerification = supportsDeviceVerification;
	}
	
	private Set<HelpData> helpTexts;
	/**
		This is the inverse end.
		@see HelpData#getClient()
		@hibernate.set lazy="true" inverse="true" cascade="delete"
		@hibernate.collection-key column="`client_id`"
		@hibernate.collection-one-to-many class="net.sf.basedb.core.data.HelpData"
	*/
	Set<HelpData> getHelpTexts()
	{
		return helpTexts;
	}
	
	void setHelpTexts(Set<HelpData> helpTexts)
	{
		this.helpTexts = helpTexts;
	}

	private Set<UserDeviceData> devices;
	/**
		This is the inverse end.
		@see UserDeviceData#getClient()
		@since 3.12
		@hibernate.set lazy="true" inverse="true" cascade="delete"
		@hibernate.collection-key column="`client_id`"
		@hibernate.collection-one-to-many class="net.sf.basedb.core.data.UserDeviceData"
	*/
	Set<UserDeviceData> getDevices()
	{
		return devices;
	}
	void setDevices(Set<UserDeviceData> devices)
	{
		this.devices = devices;
	}
	
	private Set<SessionData> sessions;
	/**
		This is the invers end.
		@see SessionData#getClient()
		@hibernate.set lazy="true" inverse="true" cascade="delete"
		@hibernate.collection-key column="`client_id`"
		@hibernate.collection-one-to-many class="net.sf.basedb.core.data.SessionData"
	*/
	Set<SessionData> getSessions()
	{
		return sessions;
	}
	
	void setSessions(Set<SessionData> sessions)
	{
		this.sessions = sessions;
	}

	private Set<UserClientSettingData> userSettings;
	/**
		This is the inverse end.
		@see UserClientSettingData#getClient()
		@hibernate.set lazy="true" inverse="true" cascade="delete"
		@hibernate.collection-key column="`client_id`"
		@hibernate.collection-one-to-many class="net.sf.basedb.core.data.UserClientSettingData"
	 */
	Set<UserClientSettingData> getUserSettings()
	{
		return userSettings;
	}
	
	void setUserSettings(Set<UserClientSettingData> userSettings)
	{
		this.userSettings = userSettings;
	}
	
	private Set<ClientDefaultSettingData> defaultSettings;
	/**
		This is the inverse end.
		@see ClientDefaultSettingData#getClient()
		@hibernate.set lazy="true" inverse="true" cascade="delete"
		@hibernate.collection-key column="`client_id`"
		@hibernate.collection-one-to-many class="net.sf.basedb.core.data.ClientDefaultSettingData"
	 */
	Set<ClientDefaultSettingData> getDefaultSettings()
	{
		return defaultSettings;
	}
	
	void setDefaultSettings(Set<ClientDefaultSettingData> defaultSettings)
	{
		this.defaultSettings = defaultSettings;
	}
	

	private Set<ContextData> contexts;
	/**
		This is the inverse end.
		@see ContextData#getClient()
		@hibernate.set lazy="true" inverse="true" cascade="delete"
		@hibernate.collection-key column="`client_id`"
		@hibernate.collection-one-to-many class="net.sf.basedb.core.data.ContextData"
	 */
	Set<ContextData> getContexts()
	{
		return contexts;
	}
	
	void setContexts(Set<ContextData> contexts)
	{
		this.contexts = contexts;
	}

	
}
