/*
	$Id: SchemaVersionData.java 6631 2014-11-27 12:06:57Z nicklas $

	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

/**
	This class holds information about the current schema version of the database.
	It contains only one record. All modifications to the database which requires some
	update script action on the data bumps the version number with one.

	@author Nicklas
	@version 2.0
	@base.modified $Date: 2014-11-27 13:06:57 +0100 (tors, 27 nov. 2014) $
	@hibernate.class table="`SchemaVersion`" lazy="false"
*/
public class SchemaVersionData
	extends BasicData
{

	public static final String BASE_APP_ID = "net.sf.basedb.core";
	
	public SchemaVersionData()
	{}
	
	private int schemaVersion;
	/**
		The current schema version.
		@hibernate.property column="`schema_version`" type="int" not-null="true"
	*/
	public int getSchemaVersion()
	{
		return schemaVersion;
	}
	public void setSchemaVersion(int schemaVersion)
	{
		this.schemaVersion = schemaVersion;
	}
	
	private int build;
	/**
		The build number.
		@hibernate.property column="`build`" type="int" not-null="true"
	*/
	public int getBuild()
	{
		return build;
	}
	public void setBuild(int build)
	{
		this.build = build;
	}
	
	private String appId;
	/**
		The ID of the application the schema version is valid for.
		'net.sf.basedb.core' is for the BASE core.
		@hibernate.property column="`app_id`" type="string" length="255" not-null="true" unique="true"
		@since 3.4
	*/
	public String getAppId()
	{
		return appId;
	}
	public void setAppId(String appId)
	{
		this.appId = appId;
	}
	
}
