/**
	$Id: LogManager.java 5038 2009-08-07 10:50:01Z nicklas $

	Copyright (C) 2009 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.log;

import net.sf.basedb.core.LogControl;

/**
	Manages the logging of changes made in a single transaction. The
	{@link LogManagerFactory} is asked to create a new log manager for
	each transaction. The same log manager may be re-used but only if
	it is thread-safe.

	@author Nicklas
	@version 2.13
	@base.modified $Date: 2009-08-07 12:50:01 +0200 (fre, 07 aug. 2009) $
*/
public interface LogManager
{
	/**
	 	Get the log controller that is used in this transaction.
	*/
	public LogControl getLogControl();
	
	/**
	 	Called after a successful commit of changes to the database.
	 	Note that this method is not called until after the changes have been 
	 	written to the database and the connection has been closed. If the
	 	log manager wants to add information to the database, it must be
	 	done before this method is called.
	*/
	public void afterCommit();
	
	/**
		Called after rollback. Note that this methd is not called until
		after the connection to the database has been closed, and that
		any information that the log manager has added to the database
		have also been rolled back.
	*/
	public void afterRollback();
}
