/**
	$Id: Permissions.java 6127 2012-09-14 07:28:35Z nicklas $

	Copyright (C) 2006 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.plugin;

import java.util.Collections;
import java.util.Set;

import net.sf.basedb.core.Item;
import net.sf.basedb.core.Permission;

/**
	This class holds permissions requested by a plugin. The server
	admin may or may not grant all requested permissions.

	@author nicklas
	@version 2.0
	@base.modified $Date: 2012-09-14 09:28:35 +0200 (fre, 14 sep. 2012) $
*/
public class Permissions
{
	
	private final Item itemType;
	private final Set<Permission> alwaysGranted;
	private final Set<Permission> maybeGranted;
	
	public Permissions(Item itemType, Set<Permission> alwaysGranted, Set<Permission> maybeGranted)
	{
		this.itemType = itemType;
		this.alwaysGranted = alwaysGranted == null ? null : Collections.unmodifiableSet(alwaysGranted);
		this.maybeGranted = maybeGranted == null ? null : Collections.unmodifiableSet(maybeGranted);
	}
	
	/**
		Get the item type the permissions are valid for.
	*/
	public Item getItemType()
	{
		return itemType;
	}
	/**
		Get the permissions that the plugin always should be granted, even if
		the logged in user doesn't have the permissions already. This makes it
		possible for a plugin to do things that a user normally can't do.
		@return A set with the permissions to grant, ot null to not grant any permissions
	*/
	public Set<Permission> getAlwaysGranted()
	{
		return alwaysGranted;
	}
	/**
		Get the permissions that the plugin should be granted only if the
		logged in user already have the permissions. This is the normal operation
		for plugins which doesn't use permissions at all, but must be specified 
		if permissions are used since the default is then to deny everything.
		
		@return A set with the permissions to grant, ot null to not grant any permissions
	*/
	public Set<Permission> getMaybeGranted()
	{
		return maybeGranted;
	}
	
	
	@Override
	public String toString()
	{
		return itemType + "; granted=" + alwaysGranted + "; maybe=" + maybeGranted;
	}
	
}
