/*
	$Id: HqlEntityParameterExpression.java 6127 2012-09-14 07:28:35Z nicklas $

	Copyright (C) 2011 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.query;

import java.util.Collection;

import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.Item;
import net.sf.basedb.core.BaseException;

/**
	Entity parameter expression. Accepts BasicItem or BasicData objects
	as parameter values.

	@author Nicklas
	@version 2.17
	@see Hql#entityParameter(String, net.sf.basedb.core.Item)
	@see HqlQuery#setEntityParameter(String, net.sf.basedb.core.BasicItem)
	@base.modified $Date: 2012-09-14 09:28:35 +0200 (fre, 14 sep. 2012) $
*/
public class HqlEntityParameterExpression
	implements Expression
{
	private final String name;
	private final Item itemType;

	public HqlEntityParameterExpression(String name, Item itemType)
	{
		assert name != null : "name == null";
		assert itemType != null : "itemType == null";
		this.name = name;
		this.itemType = itemType;
	}

	/*
		From the QueryElement interface
		-------------------------------------------
	*/
	@Override
	public String toQl(Query query, DbControl dc)
		throws BaseException
	{
		QueryParameter qp = query.getQueryParameter(name);
		if (qp != null) qp.setItemType(itemType);
		return ":" + name;
	}
	/**
		@return Always null
	*/
	@Override
	public Collection<? extends QueryElement> getChildren()
	{
		return null;
	}
	// -------------------------------------------
	/*
		From the Object class
		-------------------------------------------
	*/
	@Override
	public String toString()
	{
		return ":" + name + "(" + itemType.name() + ")";
	}
	/**
		This expression is equal to another HqlEntityParameterExpression if their 
		names are equal.
	*/
	@Override
	public boolean equals(Object other)
	{
		if (this == other) return true;
		if (other == null || this.getClass() != other.getClass()) return false;
		HqlEntityParameterExpression o = (HqlEntityParameterExpression)other;
		return name.equals(o.name);
	}
	@Override
	public int hashCode()
	{
		return name.hashCode();
	}
	// -------------------------------------------
	
	/**
		Get the name of the parameter.
	*/
	public String getName()
	{
		return name;
	}
	
	/**
		Get the type of entites that are accepted by the parameter.
	*/
	public Item getItemType()
	{
		return itemType;
	}
}
