/**
	$Id: SubqueryExpression.java 5320 2010-04-21 09:48:29Z nicklas $

	Copyright (C) 2008 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.query;

import java.util.Collection;

import net.sf.basedb.core.BaseException;
import net.sf.basedb.core.DbControl;
import net.sf.basedb.util.EqualsHelper;

/**
	Expression that returns the result of a query as it's value. This
	expression is used with subqueries.
	
	@author Nicklas
	@version 2.9
	@see Expressions#any(Query)
	@see Expressions#all(Query)
	@base.modified $Date: 2010-04-21 11:48:29 +0200 (ons, 21 apr. 2010) $
*/
public class SubqueryExpression
	implements Expression
{

	private final String operator;
	private final Query subquery;

	SubqueryExpression(String operator, Query subquery)
	{
		assert operator != null : "operator == null";
		assert subquery != null : "subquery == null";
		this.operator = operator;
		this.subquery = subquery;
	}
	
	/*
		From the QueryElement interface
		-------------------------------------------
	*/
	@Override
	public String toQl(Query query, DbControl dc) 
		throws BaseException
	{
		String ql = operator + " (" + subquery.toQl(dc) + ")";
		for (String name : subquery.getParameterNames())
		{
			QueryParameter qp = subquery.getQueryParameter(name);
			query.setParameter(qp.getName(), qp.getValue(), qp.getType());
		}
		return ql;
	}
	/**
		@return Always null
	*/
	@Override
	public Collection<? extends QueryElement> getChildren()
	{
		return null;
	}	
	// -------------------------------------------
	/*
		From the Object class
		-------------------------------------------
	*/
	@Override
	public String toString()
	{
		return operator + " (" + subquery.toString() + ")";
	}
	/**
		This expression is equal to another SubqueryExpression if they 
		use the same operator and reference the same subquery instance.
	*/
	@Override
	public boolean equals(Object other)
	{
		if (this == other) return true;
		if (other == null || this.getClass() != other.getClass()) return false;
		SubqueryExpression o = (SubqueryExpression)other;
		return EqualsHelper.equals(operator, o.operator) && subquery == o.subquery;
	}
	@Override
	public int hashCode()
	{
		return EqualsHelper.hashCode(operator, subquery);
	}
	// -------------------------------------------
}
