/*
	$Id: SubtractExpression.java 6127 2012-09-14 07:28:35Z nicklas $

	Copyright (C) 2005 Samuel Andersson, Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.query;

import java.util.Arrays;
import java.util.Collection;

import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.BaseException;
import net.sf.basedb.util.EqualsHelper;

/**
	Subtract one expression from another: e1 - e2.

	@author Nicklas
	@version 2.0
	@base.modified $Date: 2012-09-14 09:28:35 +0200 (fre, 14 sep. 2012) $
	@see Expressions#subtract(Expression, Expression)
*/
public class SubtractExpression
	implements Expression 
{
	private final Expression e1;
	private final Expression e2;

	SubtractExpression(Expression e1, Expression e2)
	{
		assert e1 != null : "e1 == null";
		assert e2 != null : "e2 == null";
		this.e1 = e1;
		this.e2 = e2;
	}

	/*
		From the QueryElement interface
		-------------------------------------------
	*/
	@Override
	public String toQl(Query query, DbControl dc)
		throws BaseException
	{
		return "(" + e1.toQl(query, dc) + " - " + e2.toQl(query, dc) + ")";
	}
	/**
		@return The expressions to subtract
	*/
	@Override
	public Collection<? extends QueryElement> getChildren()
	{
		return Arrays.asList(e1, e2);
	}
	// -------------------------------------------
	/*
		From the Object class
		-------------------------------------------
	*/
	@Override
	public String toString()
	{
		return "(" + e1 + " - " + e2 + ")";
	}
	/**
		This expression is equal to another AddExpression if their 
		child expressions are equal.
	*/
	@Override
	public boolean equals(Object other)
	{
		if (this == other) return true;
		if (other == null || this.getClass() != other.getClass()) return false;
		SubtractExpression o = (SubtractExpression)other;
		return EqualsHelper.equals(e1, o.e1) && EqualsHelper.equals(e2, o.e2);
	}
	@Override
	public int hashCode()
	{
		return EqualsHelper.hashCode(e1, e2);
	}
	// -------------------------------------------
}

