/*
	$Id: IntensityCalculator.java 4889 2009-04-06 12:52:39Z nicklas $

	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Martin Svensson, Gregory Vincic
	
	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util;

import java.util.Collection;

import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.Experiment;
import net.sf.basedb.core.Job;
import net.sf.basedb.core.ProgressReporter;
import net.sf.basedb.core.RawDataType;
import net.sf.basedb.core.data.RawData;

/**
	This interface is used together with the <code>IntensityCalculatorUtil</code>
	class to help a plugin calculate intensities from raw data spots. A plugin
	must supply an implementation of this interface to be able to use the
	{@link IntensityCalculatorUtil#createRootBioAssaySet(DbControl, Experiment, Collection, Job, IntensityCalculator, ProgressReporter)}.
	
	<p>
	One simple but powerful implementation is available from the {@link 
	IntensityCalculatorUtil#createJepIntensityCalculator(DbControl, RawDataType, String[])}
	It creates an intensity calculator that parses a string with a mathematical 
	expression.
	
	@author Nicklas
	@version 2.0
	@base.modified $Date: 2009-04-06 14:52:39 +0200 (mån, 06 apr. 2009) $
*/
public interface IntensityCalculator
{
	/**
		Calculate intensities from a raw data spot.
		
		@param rawData The raw data object the intensities should
			be calculated from
		@return An array of floats, or null if no intensities could
			be calculated
	*/
	public float[] calculateIntensities(RawData rawData);
}
