/**
	$Id: PriorityComparator.java 5570 2011-02-16 13:49:40Z nicklas $

	Copyright (C) 2011 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util;

import java.util.Collection;
import java.util.Comparator;
import java.util.SortedSet;

/**

	A comparator implemenation that sorts a given set of
	objects before all other object. 

	@author Nicklas
	@since 2.17
	@base.modified $Date: 2011-02-16 14:49:40 +0100 (ons, 16 feb. 2011) $
*/
public class PriorityComparator<T>
	implements Comparator<T>
{

	private final Collection<T> priority;
	private final Comparator<? super T> parent;
	
	/**
		Create a new comparator.

		@param priority A collection containing the objects that should be
			sorted first
		@param parent The parent comparator used to sort the objects
	*/
	public PriorityComparator(Collection<T> priority, Comparator<? super T> parent)
	{
		this.priority = priority;
		this.parent = parent;
	}
	
	/**
		Create a new comparator using the same sort order as the given
		sorted set.
	
		@param priority A collection containing the objects that should be
			sorted first
	*/
	public PriorityComparator(SortedSet<T> priority)
	{
		this.priority = priority;
		this.parent = priority.comparator();
	}
	
	/*
		From the Comparator interface
		-----------------------------
	*/
	@Override
	public int compare(T o1, T o2)
	{
		boolean p1 = priority.contains(o1);
		boolean p2 = priority.contains(o2);
		if (p1 == p2)
		{
			return parent.compare(o1, o2);
		}
		return p1 ? -1 : 1;
	}
	// ------------------------------
	
}
