/**
	$Id: StringLengthComparator.java 5575 2011-02-18 12:23:23Z nicklas $

	Copyright (C) 2010 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util;

import java.util.Comparator;

/**
	A comparator implementation for strings that sorts them according
	to their length. Shortest strings are sorted first. Strings of equal
	length are sorted in their natural order.

	@author Nicklas
	@since 2.16.2
	@base.modified $Date: 2011-02-18 13:23:23 +0100 (fre, 18 feb. 2011) $
*/
public class StringLengthComparator
	implements Comparator<String>
{

	/**
		Create a new string length comparator instance.
	*/
	public StringLengthComparator()
	{}
	
	/*
		From the Comparator interface
		------------------------------
	*/
	@Override
	public int compare(String o1, String o2)
	{
		if (o1 == o2) return 0;
		int length1 = o1 == null ? 0 : o1.length();
		int length2 = o2 == null ? 0 : o2.length();
		if (length1 != length2) return length1 - length2;
		if (length1 == 0) return 0;
		return o1.compareTo(o2);
	}
	// -------------------------------
}
