/**
	$Id: CdfValidationAction.java 5623 2011-05-06 12:09:13Z nicklas $

	Copyright (C) 2011 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.affymetrix;

import affymetrix.fusion.cdf.FusionCDFData;
import net.sf.basedb.core.ArrayDesign;
import net.sf.basedb.core.DataFileType;
import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.FileSetMember;
import net.sf.basedb.core.InvalidDataException;
import net.sf.basedb.core.InvalidRelationException;
import net.sf.basedb.util.fileset.SingleFileValidationAction;

/**
	Action for validation of CDF files in a file set. The
	CDF file must be connected with an {@link ArrayDesign}.
	<p>
	
	This class is just a wrapper for {@link CdfValidator} so
	that we can hook the validation into the extensions system.
	
	@author Nicklas
	@since 3.0
	@base.modified $Date: 2011-05-06 14:09:13 +0200 (fre, 06 maj 2011) $
*/
public class CdfValidationAction
	extends SingleFileValidationAction
{

	private final DbControl dc;
	private final ArrayDesign design;
	private final CdfValidator validator;
	
	/**
		Create a new action. 
		@param dc An open DbControl
		@param design The array design the CDF file is connected with
	*/
	public CdfValidationAction(DbControl dc, ArrayDesign design)
	{
		super(DataFileType.AFFYMETRIX_CDF);
		this.dc = dc;
		this.design = design;
		this.validator = new CdfValidator();
	}

	/*
		From the ValidationAction interface
		-----------------------------------
	*/
	@Override
	public void validateAndExtractMetadata()
		throws InvalidDataException, InvalidRelationException
	{
		FileSetMember cdfMember = getAcceptedFile();
		FusionCDFData cdfData = validator.loadCdfFile(cdfMember.getFile());
		validator.copyMetadata(cdfData, design);
	}

	@Override
	public void resetMetadata()
	{
		validator.resetMetadata(design);
	}
	// -----------------------------------

}
