/**
	$Id: BfsParser.java 7551 2018-12-12 14:41:10Z nicklas $

	Copyright (C) 2009 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.bfs;

/**
	Interface that it is recommended that all BFS parsers should implement.
	The main purpose is to expose information about the parsing progress to
	interested parties, for example, {@link EventHandler}:s.

	@author Nicklas
	@version 2.15
	@base.modified $Date: 2018-12-12 15:41:10 +0100 (ons, 12 dec. 2018) $
*/
public interface BfsParser
	extends AutoCloseable
{
	/**
		Get the filename of the file that is being parsed.
		@return The filename or null if not known
	*/
	public String getFilename();

	/**
		Get the size of the file that is being parsed.
		@return The size of the file or -1 if not known
	*/
	public long getFileSize();

	
	/**
		Get the current line number.
		@return The line number, starting at 1 for the first line in the file, or -1
			if not known
	*/
	public int getCurrentLine();
	
	/**
		Get the number of parsed bytes so far.
		@return The number of bytes that has been parsed, or -1 if not
			known
	*/
	public long getParsedBytes();
	
	/**
		Close the parser and relase underlying system resources that
		are associated with it.
	*/
	@Override
	public void close();
	
}
