/**
	$Id: DiskInputStreamLocator.java 5225 2010-01-29 13:34:03Z nicklas $

	Copyright (C) 2009 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.bfs;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;


/**
	Input stream locator implementation that works with files on the
	local file system. The files must be located in the specified root 
	directory. Subdirectories or parent paths are not supported.

	@author Nicklas
	@version 2.15
	@base.modified $Date: 2010-01-29 14:34:03 +0100 (fre, 29 jan. 2010) $
*/
public class DiskInputStreamLocator
	implements InputStreamLocator
{

	private final java.io.File dir;

	/**
		Create a new input stream locator.
		@param dir The directory in the local file system in which the
			files should be located
		@throws NullPointerException If the dir parameter is null
		@throws FileNotFoundException If the given path is not an existing directory
	*/
	public DiskInputStreamLocator(java.io.File dir)
		throws IOException
	{		
		if (dir == null) throw new NullPointerException("dir");
		if (!dir.isDirectory()) throw new FileNotFoundException(dir.toString());
		this.dir = dir;
	}
	
	/**
		Finds and opens an input stream to the file with the given filename.
	*/
	@Override
	public InputStream getInputStream(String filename) 
		throws IOException
	{
		java.io.File file = new java.io.File(dir, filename);
		if (!file.exists()) throw new FileNotFoundException("File not found: " + file);
		return new FileInputStream(file);
	}

	@Override
	public long getSize(String filename)
	{
		java.io.File file = new java.io.File(dir, filename);
		return file.length();
	}

}
