/**
	$Id: ExtraFileImporter.java 5238 2010-02-09 10:45:56Z nicklas $

	Copyright (C) 2010 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.bfs;

import java.io.IOException;

import net.sf.basedb.core.File;
import net.sf.basedb.util.importer.spotdata.BfsImporter;

/**
	Implementors are responsible for importing extra files specified in
	the BFS metadata file into the BASE file system.

	@author Nicklas
	@since 2.15
	@base.modified $Date: 2010-02-09 11:45:56 +0100 (tis, 09 feb. 2010) $
*/
public interface ExtraFileImporter
{
	/**
		Import the file data into a file in the BASE file system. The 
		{@link BfsImporter} will call this method once for each extra 
		file (entries starting with 'x-') in the metadata file.
		The implementation is supposed to create a file in the BASE file
		system or link to an existing file. The returned file will be 
		automatically linked with the child bioassay set.
		
		@param filename The filename of the file that is being imported
		@param locator A locator implementation that should be used to
			find the file data if needed
		@return The file in the BASE file system or null if no file was created
		@throws IOException If there is a problem reading the file data
	*/
	public File importExtraFile(String filename, InputStreamLocator locator)
		throws IOException;
}
