/**
	$Id: GenericBaseDataWriterFactory.java 5212 2010-01-12 13:21:49Z nicklas $

	Copyright (C) 2009 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.bfs;

import java.io.IOException;
import java.io.OutputStream;

import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.Directory;
import net.sf.basedb.core.File;

/**
	Generic implementation of a data writer factory that create
	files in the BASE file system.

	@author Nicklas
	@version 2.15
	@base.modified $Date: 2010-01-12 14:21:49 +0100 (tis, 12 jan. 2010) $
*/
public class GenericBaseDataWriterFactory<T>
	extends AbstractDataWriterFactory<T>
{

	private final DbControl dc;
	private final Directory dir;
	
	/**
		Create a new factory that creates files in the given
		directory. The directory should already exist.
		@param dir The directory to create files in
	*/
	public GenericBaseDataWriterFactory(DbControl dc, Directory dir, 
		FilenameGenerator<T> filenameGenerator)
		throws IOException
	{
		super(filenameGenerator);
		if (dir == null) throw new NullPointerException("dir");
		this.dc = dc;
		this.dir = dir;
	}

	/**
		Create a new file in the data directory with the given file
		name.
	*/
	@Override
	protected OutputStream getOutputStream(String filename) 
		throws IOException
	{
		File file = File.getFile(dc, dir, filename, true);
		file.setName(filename);
		setFileProperties(file);
		if (!file.isInDatabase()) dc.saveItem(file);
		return file.getUploadStream(false);
	}
	
	/**
		Set file properties on the newly created file object. The default
		implementation sets the character set to UTF-8 and the MIME type
		to text/plain. A subclass may override this method to set other 
		properties.
		@param file The new file
	*/
	protected void setFileProperties(File file)
	{
		file.setCharacterSet("UTF-8");
		file.setMimeType("text/plain");
	}
}
