/**
	$Id: MultiEventHandler.java 5224 2010-01-27 13:03:33Z nicklas $

	Copyright (C) 2009 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.bfs;

import java.util.ArrayList;
import java.util.List;

/**
	Event handler implementation that forwards a single event to multiple
	event handlers. This is useful since a parser only sends the event
	to a single handler. The event is forwarded to all registered event 
	handlers in the order they have been registered.
	
	@author Nicklas
	@version 2.15
	@base.modified $Date: 2010-01-27 14:03:33 +0100 (ons, 27 jan. 2010) $
*/
public class MultiEventHandler
	implements EventHandler
{

	
	private List<EventHandler> handlers;
	/**
		Create a new event handler. Use {@link #addEventHandler(EventHandler)}
		to add the event handlers that the events should be forwarded to.
	 */
	public MultiEventHandler()
	{
		this.handlers = new ArrayList<EventHandler>();
	}
	
	/**
		Adds an event handler.
	*/
	public void addEventHandler(EventHandler e)
	{
		if (e == null) throw new NullPointerException("e");
		handlers.add(e);
	}
	
	/**
		Removes an event handler.
	*/
	public void removeEventHandler(EventHandler e)
	{
		handlers.remove(e);
	}
	
	/**
		Resends the incoming event to all registered event handlers.
	*/
	@Override
	public <T> void handleEvent(EventType<T> eventType, T eventData, BfsParser parser)
	{
		for (EventHandler e : handlers)
		{
			e.handleEvent(eventType, eventData, parser);
		}
	}

}
