/**
	$Id $

	Copyright (C) 2009 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.encode;

/**
	Interface for encoding and decoding strings to make them work in a certain
	context. For example, in tab-separated text files tabs, newlines, etc. need
	to be encoded or the number of columns or lines will be incorrect.
	<p>
	An encoder is usually paired with a decoder. It is not a requirement that the
	encoding is symmetrical. If the encoding is symmetrical the result of encoding
	and then decoding must be equal the original string and so must the result of 
	decoding and then encoding.
	<p>
	It is up to the implementation how null values are handled. Some implementations
	may not support null and may throw an exception. Note that null value handling must
	also be symmetrical if {@link #isSymmetrical()} returns true.
	
	@since 2.15
	@author Nicklas
*/
public interface EncoderDecoder 
{
	/**
		@return TRUE if the encoder is symmetrical, FALSE if not
	*/
	public boolean isSymmetrical();
	
	/**
		@param s The string to encode
		@return The encoded string
	*/
	public String encode(String s);
	
	/**
		@param s The string to decode
		@return The decoded string
	*/
	public String decode(String s);
	
}
