/**
	$Id: ExportableField.java 5385 2010-08-13 10:48:17Z nicklas $

	Copyright (C) 2009 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.export.spotdata;

import net.sf.basedb.core.Type;
import net.sf.basedb.util.formatter.Formatter;

/**
	Interface that represents an exportable field.
	It is recommended that implementations override {@link Object#equals(Object)}
	and {@link Object#hashCode()} methods to make it possible for users
	to check if a given field is present or not in a list of already
	existing fields. A typical implementation should only compare itself
	to fields of the same class that export the same information with the
	same title.

	@author Nicklas
	@version 2.12
	@base.modified $Date: 2010-08-13 12:48:17 +0200 (fre, 13 aug. 2010) $
*/
public interface ExportableField
{

	/**
		Get the column header.
	*/
	public String getTitle();

	/**
		Get the data type of the field.
		@return A type object or null if not known
		@since 2.15
	*/
	public Type getType();
	
	/**
		Get a formatter that converts the values in this field to strings.
		@return A formatter or null to use default formatting (normally this means
			calling the toString() method).
	*/
	public Formatter<?> getFormatter();
	
}
