/**
	$Id: CombiningEventFilter.java 4515 2008-09-11 20:08:14Z jari $

	Copyright (C) 2008 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.extensions.events;

import java.util.Collection;

import net.sf.basedb.util.extensions.Extension;
import net.sf.basedb.util.extensions.ExtensionPoint;

/**
	Event filter that only passes on events based on multiple
	other event filters. Given a collection of event filters,
	this filter can pass on the event if at least one of the
	filters in the collection does or if all of them does.

	@author nicklas
	@version 2.8
	@base.modified $Date: 2008-09-11 22:08:14 +0200 (tors, 11 sep. 2008) $
 */
public class CombiningEventFilter
	implements EventFilter
{

	private final Collection<EventFilter> filters;
	private final boolean allMustPass;
	
	/**
		Create a new combining event filter. This filter will pass events
		depending on how many of the other event filters passes the event.
		
		@param filters A collection of event filters
		@param allMustPass TRUE if the event must pass all filters to
			pass this filter, FALSE if the event must pass at least one
			filter to pass this filter
	*/
	public CombiningEventFilter(Collection<EventFilter> filters, boolean allMustPass)
	{
		this.filters = filters;
		this.allMustPass = allMustPass;
	}
	
	/**
		@return TRUE if the event passes the filters
	*/
	@Override
	public boolean shouldSend(EventType event, ExtensionPoint<?> extensionPoint,
			Extension<?> extension)
	{
		for (EventFilter filter : filters)
		{
			boolean pass = filter.shouldSend(event, extensionPoint, extension);
			if (pass)
			{
				if (!allMustPass) return true;
			}
			else
			{
				if (allMustPass) return false;
			}
		}
		return allMustPass;
	}

}
