/**
	$Id: AbstractJepConversionFunction.java 6127 2012-09-14 07:28:35Z nicklas $

	Copyright (C) 2007 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.jep.convert;

import net.sf.basedb.core.query.Expression;
import net.sf.basedb.core.query.Expressions;
import net.sf.basedb.core.query.Restriction;


/**
	Abstract superclass implementing the {@link JepConversionFunction}
	interface. This class throws an {@link UnsupportedOperationException}
	for the {@link #toExpression(Object)} and {@link #toRestriction(Object)}
	methods. A subclass should override at least one of the methods.
	
	@author nicklas
	@version 2.4
	@base.modified $Date: 2012-09-14 09:28:35 +0200 (fre, 14 sep. 2012) $
*/
public abstract class AbstractJepConversionFunction<T>
	implements JepConversionFunction<T>
{

	protected AbstractJepConversionFunction()
	{}
	
	/*
		From the JepConversionFunction interface
		-------------------------------------------
	*/
	/**
		@return Always FALSE
	*/
	@Override
	public boolean isFunction()
	{
		return false;
	}
	/**
		@return Always FALSE
	*/
	@Override
	public boolean isOperator()
	{
		return false;
	}
	/**
		@return Always null
	*/
	@Override
	public String getName()
	{
		return null;
	}
	/**
		@return Always null
	*/
	@Override
	public String getDescription()
	{
		return null;
	}
	/**
		Convert to a restriction and then use {@link Expressions#bool(Restriction)}
		to create a boolean expression.
	*/
	@Override
	public Expression toExpression(T node)
	{
		return Expressions.bool(toRestriction(node));
	}

	/**
		@throws UnsupportedOperationException Always
	*/
	@Override
	public Restriction toRestriction(T node)
	{
		throw new UnsupportedOperationException(getClass() + ".toRestriction()");
	}
	// -------------------------------------------

}
