/**
	$Id: JepConversionFunction.java 4515 2008-09-11 20:08:14Z jari $

	Copyright (C) 2007 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.jep.convert;


import net.sf.basedb.core.query.Expression;
import net.sf.basedb.core.query.Restriction;
import net.sf.basedb.util.jep.Jep;
import net.sf.basedb.util.jep.JepExpressionFunction;

/**
	Convert a built-in JEP function or operation to a Query
	API {@link Expression} or {@link Restriction}. Custom function
	should implement {@link JepExpressionFunction} which supports
	automatic conversion.
	
	@author nicklas
	@version 2.4
	@base.modified $Date: 2008-09-11 22:08:14 +0200 (tors, 11 sep. 2008) $
*/
public interface JepConversionFunction<T>
{
	/**
		If this converter is a built-in function. Built-in functions
		are automatically put in the enumeration return by
		{@link Jep#getFunctions()}.
		@return TRUE if it is a function, FALSE otherwise
	*/
	public boolean isFunction();
	
	/**
		If this converter is a built-in operator.
		@return TRUE if it is an operator, FALSE otherwise
	*/
	public boolean isOperator();
	
	/**
		Get the name of the function or the symbol of the operator
		@return The name or symbol or null
	*/
	public String getName();

	/**
		Get a short description of the function or operator
		@return The description or null
	*/
	public String getDescription();
	
	/**
		Convert the object to an expression.
		@param node The object to convert
		@return An expression or null
		@throws UnsupportedOperationException If this converter can't convert to
			expressions
	*/
	public Expression toExpression(T node);

	/**
		Convert the object to a restriction.
		@param node The object to convert
		@return A restriction or null
		@throws UnsupportedOperationException If this converter can't convert to
			restrictions
	*/
	public Restriction toRestriction(T node);
}
