/**
	$Id: ExperimentalFactorLoader.java 4740 2009-02-05 13:39:25Z nicklas $

	Copyright (C) 2008 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.overview.loader;

import net.sf.basedb.core.AnnotationType;
import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.Experiment;
import net.sf.basedb.core.ItemQuery;
import net.sf.basedb.core.ItemResultIterator;
import net.sf.basedb.util.overview.OverviewContext;
import net.sf.basedb.util.overview.node.ChildNodeDirection;
import net.sf.basedb.util.overview.node.NameableNameGenerator;
import net.sf.basedb.util.overview.Node;
import net.sf.basedb.util.overview.node.NodeFactory;

/**
	Node loader implementation for experimental factors. The 
	annotation types used as experimental factors are loaded
	as property-type child nodes of an experiment.
	
	@author Nicklas
	@version 2.10
	@base.modified $Date: 2009-02-05 14:39:25 +0100 (tors, 05 feb. 2009) $
*/
public class ExperimentalFactorLoader
	extends BasicItemNodeLoader<AnnotationType>
{

	public ExperimentalFactorLoader()
	{
		super("EXPERIMENTAL.FACTOR", DENY_ROOT_NODE, 
				new NameableNameGenerator<AnnotationType>("factor", "Experimental factor"));
	}
	
	/*
		From the NodeLoader interface
		------------------------------
	*/
	@Override
	public Node createPropertyNode(DbControl dc, OverviewContext context, Node experimentNode)
	{
		NodeFactory<AnnotationType> nf = getNodeFactory(dc, context);
		Node folderNode = null;
		
		// Load all experimental factors for the given experiment
		Experiment experiment = (Experiment)experimentNode.getItem(dc);
		ItemQuery<AnnotationType> query = context.initQuery(experiment.getExperimentalFactors(), "name");
		ItemResultIterator<AnnotationType> it = query.iterate(dc);
		while (it.hasNext())
		{
			AnnotationType factor = it.next();
			if (folderNode == null)
			{
				folderNode = new Node("factors", "Experimental factors", experimentNode);
			}
			createItemNode(nf, factor, null, false, folderNode, ChildNodeDirection.NONE);
		}
		postValidateFolder(nf, folderNode, experimentNode, false);
		return folderNode;
	}
	// -----------------------------------
}