/**
	$Id: NodeNameGenerator.java 5818 2011-10-21 11:15:41Z nicklas $

	Copyright (C) 2008 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.overview.node;

import net.sf.basedb.core.BasicItem;
import net.sf.basedb.util.overview.Node;

/**
	A name generator is an object that can create the name and
	title for a node when given the item that should be attached
	to the node. The name and title are used to create the 
	new node: {@link Node#Node(String, String, Node, BasicItem, ChildNodeDirection)}.

	@author Nicklas
	@version 2.10
	@base.modified $Date: 2011-10-21 13:15:41 +0200 (fre, 21 okt. 2011) $
*/
public interface NodeNameGenerator<I>
{

	/**
		Generate a name for a node when the item is missing.
		@param parentNode The parent node
		@return A name for the node
	*/
	public String getMissingNodeName(Node parentNode);

	/**
		Generate a title for a node when the item is missing.
		@param parentNode The parent node
		@return A title for the node
	*/
	public String getMissingNodeTitle(Node parentNode);

	/**
		Generate a name for a node when the item exists, but
		the current user doesn't have permission to access read
		the item.
		@param parentNode The parent node
		@return A name for the node
	*/
	public String getDeniedNodeName(Node parentNode);

	/**
		Generate a title for a node when the item exists, but
		the current user doesn't have permission to access read
		the item.
		@param parentNode The parent node
		@return A name for the node
	*/
	public String getDeniedNodeTitle(Node parentNode);
	
	/**
		Generate a name for the new node that is about to be
		created.
		@param item The item that is attached to the node (never null)
		@param parentNode The parent node of the new node
		@return A name for the node
	*/
	public String getNodeName(I item, Node parentNode);
	
	/**
		Generate a title for the new node that is about to be
		created.
		@param item The item that is attached to the node (never null)
		@param parentNode The parent node of the new node
		@return A title for the node
	*/
	public String getNodeTitle(I item, Node parentNode);
	
}
