/**
	$Id: AnyToAnyValidator.java 5651 2011-06-08 13:00:33Z nicklas $

	Copyright (C) 2010 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.overview.validator;

import net.sf.basedb.core.AnyToAny;
import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.ItemNotFoundException;
import net.sf.basedb.core.PermissionDeniedException;
import net.sf.basedb.util.overview.Fix;
import net.sf.basedb.util.overview.Node;
import net.sf.basedb.util.overview.OverviewContext;
import net.sf.basedb.util.overview.Validator;

/**
	Validator implementation for any-to-any links. Validation rules:
	<ul>
	<li>Missing item: {@link Validator#MISSING_ANYTOANY}
	<li>Access denied: {@link Validator#DENIED_ANYTOANY}
	</ul>

	@author Nicklas
	@since 2.17
	@base.modified $Date: 2011-06-08 15:00:33 +0200 (ons, 08 juni 2011) $
*/
public class AnyToAnyValidator
	extends BasicNodeValidator<AnyToAny>
{

	public AnyToAnyValidator()
	{
		super(null, null);
	}
	
	/*
		From BasicNodeValidator class
		-----------------------------
	*/
	@Override
	public void postValidate(DbControl dc, OverviewContext context, Node node, Node parentNode)
	{
		super.postValidate(dc, context, node, parentNode);
		if (parentNode.getNodeType() == Node.Type.FOLDER) parentNode = parentNode.getParent();
		
		AnyToAny any = (AnyToAny)node.getItem();
		try
		{
			any.getTo();
		}
		catch (PermissionDeniedException ex)
		{
			context.createFailure(Validator.DENIED_ANYTOANY, node, 
				"Access denied to " + any.getName() + " (" + any.getToType() + ")");
		}
		catch (ItemNotFoundException ex)
		{
			context.createFailure(Validator.MISSING_ANYTOANY, node, 
					"Missing " + any.getName() + " (" + any.getToType() + "; id=" + any.getToId() + ")");
		}
	}
	
	/**
		@return Always "null"
	*/
	@Override
	protected Fix getMissingItemFix(DbControl dc, Node parentNode)
	{
		return null;
	}
	// -------------------------------
}
