/**
	$Id: ArrayBatchValidator.java 5651 2011-06-08 13:00:33Z nicklas $

	Copyright (C) 2008 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.overview.validator;

import net.sf.basedb.core.ArrayBatch;
import net.sf.basedb.core.DbControl;
import net.sf.basedb.util.overview.Fix;
import net.sf.basedb.util.overview.Validator;
import net.sf.basedb.util.overview.Node;

/**
	Validator implementation for array batch. Validation rules:
	<ul>
	<li>Missing item: {@link Validator#MISSING_ARRAYBATCH}
	<li>Access denied: {@link Validator#DENIED_ARRAYBATCH}
	</ul>

	@author Nicklas
	@version 2.10
	@base.modified $Date: 2011-06-08 15:00:33 +0200 (ons, 08 juni 2011) $
*/
public class ArrayBatchValidator
	extends NameableNodeValidator<ArrayBatch>
{
	
	public ArrayBatchValidator()
	{
		super(Validator.MISSING_ARRAYBATCH, Validator.DENIED_ARRAYBATCH);
	}
	
	/* 
		From BasicValidator class
		-------------------------
	*/
	/**
		The suggested fix is to add an array batch to the
		slide.
	*/
	@Override
	protected Fix getMissingItemFix(DbControl dc, Node parentNode)
	{
		return new Fix("Add array batch to array slide", parentNode.getItem());
	}
	// ----------------------------
}
