/**
	$Id: CloseResourceInputStream.java 5582 2011-03-15 12:55:59Z nicklas $

	Copyright (C) 2011 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.uri;

import java.io.Closeable;
import java.io.FilterInputStream;
import java.io.IOException;
import java.io.InputStream;

/**
	Inputstream filter that closes a given resource whenever the
	parent input stream is closed.

	@author Nicklas
	@since 3.0
	@base.modified $Date: 2011-03-15 13:55:59 +0100 (tis, 15 mars 2011) $
*/
public class CloseResourceInputStream
	extends FilterInputStream
{

	private final Closeable resource;
	/**
		Create a new stream.
		@param parent The parent input stream
		@param resource The resource to close when the {@link #close()}
			method is called.
	 */
	public CloseResourceInputStream(InputStream parent, Closeable resource)
	{
		super(parent);
		this.resource = resource;
	}
	
	/*
		From the InputStream class
		--------------------------
	*/
	/**
		Make sure the client connection manager is closed when the
		file has been completely downloaded.
	*/
	@Override
	public void close() 
		throws IOException 
	{
		try
		{
			super.close();
		}
		finally
		{
			resource.close();
		}
	}
	// --------------------------
		
}
