/**
	$Id: HttpConnectionManagerFactory.java 5599 2011-03-31 11:38:56Z nicklas $

	Copyright (C) 2011 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.uri.http;

import java.net.URI;

import net.sf.basedb.util.uri.ConnectionParameters;
import net.sf.basedb.util.uri.ConnectionManager;
import net.sf.basedb.util.uri.ConnectionManagerFactory;

/**
	Connection manager factory for HTTP and HTTPS URI:s. Auto-detection
	is supported for "http" and "https" URI:s. 
	
	@author Nicklas
	@since 3.0
	@base.modified $Date: 2011-03-31 13:38:56 +0200 (tors, 31 mars 2011) $
	@see HttpConnectionManager
*/
public class HttpConnectionManagerFactory
	implements ConnectionManagerFactory
{

	private String id;
	private String name;
	private String description;
	
	/**
		Create a new http connection manager factory.
	*/
	public HttpConnectionManagerFactory()
	{}
	
	/*
		From the ConnectionManagerFactory interface
		-------------------------------------------
	*/
	@Override
	public String getId()
	{
		return id;
	}

	@Override
	public String getDisplayName()
	{
		return name;
	}

	@Override
	public String getDescription()
	{
		return description;
	}
	
	@Override
	public boolean useAutoDetection()
	{
		return true;
	}
	
	@Override
	public boolean supports(URI uri)
	{
		if (uri == null) throw new NullPointerException("uri");
		String scheme = uri.getScheme();
		return "http".equals(scheme) || "https".equals(scheme);
	}
	
	@Override
	public ConnectionManager createConnectionManager(URI uri, ConnectionParameters parameters)
	{
		return new HttpConnectionManager(uri, parameters);
	}
	// --------------------------------------------

	/**
		Initialize this factory with some information.
	*/
	public void init(String id, String name, String description)
	{
		this.id = id;
		this.name = name;
		this.description = description;
	}
	
}
