<%-- $Id: edit_event.jsp 7605 2019-02-26 10:10:15Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2010 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.Item"
	import="net.sf.basedb.core.Hardware"
	import="net.sf.basedb.core.Kit"
	import="net.sf.basedb.core.Protocol"
	import="net.sf.basedb.core.ItemContext"
	import="net.sf.basedb.core.Permission"
	import="net.sf.basedb.core.Include"
	import="net.sf.basedb.core.BioPlateEvent"
	import="net.sf.basedb.core.ItemQuery"
	import="net.sf.basedb.core.ItemResultList"
	import="net.sf.basedb.core.PermissionDeniedException"
	import="net.sf.basedb.core.BaseException"
	import="net.sf.basedb.core.query.Orders"
	import="net.sf.basedb.core.query.Hql"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.util.Values"
	import="net.sf.basedb.core.plugin.GuiContext"
	import="net.sf.basedb.util.formatter.Formatter"
	import="net.sf.basedb.clients.web.formatter.FormatterFactory"
	import="net.sf.basedb.clients.web.formatter.FormatterSettings"
	import="net.sf.basedb.clients.web.extensions.ExtensionsControl"
	import="net.sf.basedb.clients.web.extensions.JspContext"
	import="net.sf.basedb.clients.web.extensions.edit.EditUtil"
	import="net.sf.basedb.clients.web.extensions.tabcontrol.TabAction"
	import="net.sf.basedb.util.extensions.ExtensionsInvoker"
	import="java.util.List"
	import="java.util.Set"
	import="java.util.HashSet"
	import="java.util.Date"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%@ taglib prefix="t" uri="/WEB-INF/tab.tld" %>
<%@ taglib prefix="ext" uri="/WEB-INF/extensions.tld" %>
<%
final Item itemType = Item.BIOPLATEEVENT;
final SessionControl sc = Base.getExistingSessionControl(pageContext, true);
final ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, null, null);
final int itemId = cc.getId();
final String ID = sc.getId();
final float scale = Base.getScale(sc);
final DbControl dc = sc.newDbControl();
try
{
	if (itemId == 0) throw new PermissionDeniedException(Permission.CREATE, "bioplate event");
	String title = null;
	BioPlateEvent event = BioPlateEvent.getById(dc, itemId);
	event.checkPermission(Permission.WRITE);
	
	boolean readCurrentHardware = true;
	Hardware currentHardware = null;
	boolean readCurrentProtocol = true;
	Protocol currentProtocol = null;
	boolean readCurrentKit = true;
	Kit currentKit = null;
	
	// Load recently used items
	List<Hardware> recentHardware = cc.getRecent(dc, Item.HARDWARE);
	List<Protocol> recentProtocols = cc.getRecent(dc, Item.PROTOCOL);
	List<Kit> recentKits = cc.getRecent(dc, Item.KIT);
	
	cc.setObject("item", event);
	title = "Edit bioplate event -- " + HTML.encodeTags(event.getName());

	try
	{
		currentHardware = event.getHardware();			
	}
	catch (PermissionDeniedException ex)
	{
		readCurrentHardware = false;
	}
	try
	{
		currentProtocol = event.getProtocol();
	}
	catch (PermissionDeniedException ex)
	{
		readCurrentProtocol = false;
	}
	try
	{
		currentKit = event.getKit();			
	}
	catch (PermissionDeniedException ex)
	{
		readCurrentKit = false;
	}

	final Formatter<Date> dateFormatter = FormatterFactory.getDateFormatter(sc);
	final String dateFormat = FormatterSettings.getDateFormat(sc);
	final String jsDateFormat = HTML.javaScriptEncode(dateFormat);
	final String htmlDateFormat = HTML.encodeTags(dateFormat);

	JspContext jspContext = ExtensionsControl.createContext(dc, pageContext, GuiContext.item(itemType), event);
	ExtensionsInvoker<TabAction> invoker = EditUtil.useEditExtensions(jspContext);
	%>
	<base:page type="popup" title="<%=title%>" id="edit-page">
	<base:head scripts="tabcontrol-2.js,~events.js" styles="tabcontrol.css">
		<ext:scripts context="<%=jspContext%>" />
		<ext:stylesheets context="<%=jspContext%>" />
	</base:head>
	<base:body>
		<h1><%=title%> <base:help tabcontrol="settings" /></h1>
		<form action="index.jsp?ID=<%=ID%>" method="post" name="event">
		<input type="hidden" name="cmd" value="UpdateItem">

		<t:tabcontrol id="settings"
			subclass="content dialogtabcontrol"
			position="bottom"  remember="<%=event != null%>" 
			extensions="<%=invoker%>">
		<t:tab id="info" title="Bioplate event" helpid="bioplateevent.edit">
			<table class="fullform input100">
			<tr>
				<th>Name</th>
				<td><input class="text required auto-init" data-auto-init="<%=event == null ? "focus-select" : "focus" %>"
					type="text" name="name" 
					value="<%=HTML.encodeTags(event.getName())%>" 
					maxlength="<%=BioPlateEvent.MAX_NAME_LENGTH%>"></td>
				<td></td>
			</tr>
			<tr>
				<th>Event date</th>
				<td>
					<table>
					<tr>
					<td>
						<input class="text" type="text" name="event_date" id="event_date" style="width: 15em;"
							value="<%=HTML.encodeTags(dateFormatter.format(event.getEventDate()))%>" 
							maxlength="20" title="Enter date in format: <%=htmlDateFormat%>">
					</td>
					<td>
						<base:calendar textarea="event_date" title="Event date" />
					</td>
					</tr>
					</table>
				</td>
				<td></td>
			</tr>
			<tr>
				<th>Protocol</th>
				<td>
					<base:select 
						id="protocol_id"
						clazz="selectionlist"
						required="false"
						current="<%=currentProtocol%>"
						denied="<%=!readCurrentProtocol%>"
						recent="<%=recentProtocols%>"
					/>
				</td>
				<td></td>
			</tr>
			<tr>
				<th>Kit</th>
				<td>
					<base:select 
						id="kit_id"
						clazz="selectionlist"
						required="false"
						current="<%=currentKit%>"
						denied="<%=!readCurrentKit%>"
						recent="<%=recentKits%>"
					/>
				</td>
				<td></td>
			</tr>
			<tr>
				<th>Hardware</th>
				<td>
					<base:select 
						id="hardware_id"
						clazz="selectionlist"
						required="false"
						current="<%=currentHardware%>"
						denied="<%=!readCurrentHardware%>"
						recent="<%=recentHardware%>"
					/>
				</td>
				<td></td>
			</tr>
			<tr class="dynamic">
				<th>Description</th>
				<td>
					<textarea class="text" rows="6" name="description" id="description"
						><%=HTML.encodeTags(event.getDescription())%></textarea>
				</td>
				<td style="width: 20px;">
					<base:zoom textarea="description" title="Description" />
				</td>
			</tr>
			</table>
		</t:tab>
		</t:tabcontrol>
		</form>
		
		<div class="legend">
			<base:icon image="required.png" />= required information
		</div>

		<base:buttongroup subclass="dialogbuttons">
			<base:button id="btnSave" title="Save" />
			<base:button id="close" title="Cancel" />
		</base:buttongroup>
	</base:body>
	</base:page>
	<%
}
finally
{
	if (dc != null) dc.close();
}
%>