<%-- $Id: main.jsp 7605 2019-02-26 10:10:15Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg
	Copyright (C) 2007 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	This is the front page of BASE. It displays a login form
	and some of the relevant news items.

	@param login The value to display in the login input field.
	@param error An error message that should be displayed

	@author Nicklas
	@version 2.0
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.Application"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.News"
	import="net.sf.basedb.core.ItemQuery"
	import="net.sf.basedb.core.ItemResultIterator"
	import="net.sf.basedb.core.query.Orders"
	import="net.sf.basedb.core.query.Hql"
	import="net.sf.basedb.util.extensions.ExtensionsInvoker"
	import="net.sf.basedb.util.extensions.ActionIterator"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.util.formatter.Formatter"
	import="net.sf.basedb.clients.web.extensions.ExtensionsControl"
	import="net.sf.basedb.clients.web.extensions.JspContext"
	import="net.sf.basedb.clients.web.formatter.FormatterFactory"
	import="net.sf.basedb.clients.web.servlet.RssNewsFeed"
	import="net.sf.basedb.clients.web.extensions.login.LoginFormAction"
	import="net.sf.basedb.clients.web.extensions.login.FieldInfo"
	import="net.sf.basedb.clients.web.extensions.login.PasswordLoginFormFactory"
	import="net.sf.basedb.util.Values"
	import="java.util.Date"
	import="java.util.Map"
	import="java.util.TreeMap"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%@ taglib prefix="ext" uri="/WEB-INF/extensions.tld" %>
<%! 
// If value is null, return "", else <prefix>+<value>+<suffix>
String valueIfNotNull(String prefix, String value, String suffix)
{
	return value == null ? "" : prefix+value+suffix;
}
%>
<%
final String login = Values.getString(request.getParameter("login"), "");
final String error = Values.getString(request.getParameter("error"), null);
final boolean again = Values.getBoolean(request.getParameter("again"));
final String requestedLoginForm = Values.getString(request.getParameter("loginForm"), null);
final String root = request.getContextPath()+"/";

final SessionControl sc = Base.getSessionControl(pageContext, true);
final String ID = sc.getId();
final Formatter<Date> dateFormatter = FormatterFactory.getDateFormatter(sc);
final DbControl dc = sc.newDbControl();

try
{
	String broadcastTitle = (String)application.getAttribute("broadcast.title");
	String broadcastMessage = (String)application.getAttribute("broadcast.message");
	boolean denyLogin = Boolean.TRUE.equals(application.getAttribute("broadcast.deny-login"));
	
	ItemResultIterator<News> news = null;
	JspContext jspContext = ExtensionsControl.createContext(dc, pageContext);
	ExtensionsInvoker<LoginFormAction> invoker = ExtensionsControl.useExtensions(jspContext, "net.sf.basedb.clients.web.login-form");

	LoginFormAction loginAction = null;
	String selectedLoginForm = null;
	Map<String, String> allForms = new TreeMap<String, String>();
	
	ActionIterator<LoginFormAction> it = invoker.iterate();
	while (it.hasNext())
	{
		LoginFormAction action = it.next();
		if (action != null)
		{
			String formId = action.getId();
			if (formId == null) formId = it.getExtension().getId();
			String displayName = action.getDisplayName();
			if (displayName == null) displayName = it.getExtension().getAbout().getName();
			allForms.put(formId, displayName);
			
			if (loginAction == null || formId.equals(requestedLoginForm))
			{
				loginAction = action;
				selectedLoginForm = formId;
			}
		}
	}
	if (loginAction == null)
	{
		loginAction = PasswordLoginFormFactory.INSTANCE;
		selectedLoginForm = loginAction.getId();
	}

	FieldInfo loginField = loginAction.getLoginField();
	FieldInfo passwordField = loginAction.getPasswordField();
	FieldInfo extraField = loginAction.getExtraField();
	%>
	<base:page type="default">
	<base:head styles="login.css" scripts="~login.js">
		<ext:scripts context="<%=jspContext%>" />
		<ext:stylesheets context="<%=jspContext%>" />
	</base:head>
	<base:body style="padding-top: 5em;" data-login-form="<%=HTML.encodeTags(selectedLoginForm)%>" data-requested-form="<%=HTML.encodeTags(requestedLoginForm) %>">
		<form name="login" action="login.jsp" method="post">
		<input type="hidden" name="ID" value="<%=ID%>">
		<input type="hidden" name="again" value="<%=again?1:0%>">
		<input type="hidden" name="useAutoStartPage" value="1">
		<input type="hidden" name="deviceToken" value="">
		
		<table style="margin: auto; max-width: 700px; display: none;" id="the-login-form">
		<tr>
		<td>
			<%
			if (allForms.size() > 1)
			{
				%>
				<div style="text-align: right; margin-bottom: 0.25em;">
					<b>Login with</b>
					<select name="loginForm" id="loginForm" style="min-width: 10em;">
					<%
					for (Map.Entry<String, String> entry : allForms.entrySet())
					{
						String formId = entry.getKey();
						%>
						<option value="<%=formId%>" <%=formId.equals(selectedLoginForm) ? "selected" : ""%>><%=HTML.encodeTags(entry.getValue()) %>
						<%
					}
					%>
					</select>
				</div>
				<%
			}
			else if (selectedLoginForm != null)
			{
				%>
				<input type="hidden" name="loginForm" value="<%=selectedLoginForm%>">
				<%
			}
			if (loginAction.getHelp() != null)
			{
				%>
				<div class="messagecontainer help" style="margin-bottom: 1em; font-style: italic;" id="login-help">
				<%=loginAction.getHelp() %>
				</div>
				<%
			}
			if (error != null) 
			{
				%>
				<div class="messagecontainer error" style="margin-top: 1em; margin-bottom: 1em;"><%=error%></div>
				<%
			}
			%>
			<table style="width: 100%; border-collapse: separate;">
			<tr>
				<td class="base-logo"><img src="images/baselogo.png" alt="BASE logo"></td>
				<td style="width: 515px;">
					<div id="loginform">
					<table style="width: 100%;">
						<tr <%=valueIfNotNull("class=\"", loginField.getClazz(), "\"")%> id="login-row">
							<th class="bg-filled-100"><%=loginField.getPrompt() %></th>
							<td colspan="2"><input class="text" name="login" id="login"
								type="<%=loginField.hasHiddenCharacters() ? "password" : "text"%>"
								value="<%=loginAction.rememberLastLogin() ? HTML.encodeTags(login) : ""%>" 
								<%=denyLogin ? "disabled" : ""%>
								<%=valueIfNotNull("style=\"", loginField.getStyle(), "\"") %>
								<%=valueIfNotNull("title=\"", loginField.getTooltip(), "\"") %>
								<%=valueIfNotNull("placeholder=\"", loginField.getPlaceHolder(), "\"") %>
								<%=loginAction.rememberLastLogin() ? "" : "autocomplete=\"off\" data-use-last-login=\"0\""%>
								maxlength="100"	
								tabindex="1">
							</td>
						</tr>
						<tr <%=valueIfNotNull("class=\"", passwordField.getClazz(), "\"")%> id="password-row">
							<th class="bg-filled-100"><%=passwordField.getPrompt() %></th>
							<td><input class="text" name="password" id="password"
								type="<%=passwordField.hasHiddenCharacters() ? "password" : "text"%>"
								<%=denyLogin ? "disabled" : ""%>
								<%=valueIfNotNull("style=\"", passwordField.getStyle(), "\"") %>
								<%=valueIfNotNull("title=\"", passwordField.getTooltip(), "\"") %>
								<%=valueIfNotNull("placeholder=\"", passwordField.getPlaceHolder(), "\"") %>
								maxlength="80"
								tabindex="2">
							</td>
							<td <%=extraField != null?"rowspan=\"2\"" : "" %> style="vertical-align: bottom;">
									<base:buttongroup>
										<base:button 
											id="btnLogin"
											subclass="<%=denyLogin ? "disabled" : ""%>"
											image="login.png" title="Login" 
											tooltip="<%=HTML.encodeTags(broadcastTitle)%>" tabindex="4" 
										/>
										<base:button 
											id="close" title="Cancel" tabindex="5"
											visible="<%=again %>"
										/>
									</base:buttongroup>
							</td>
						</tr>
						<%
						if (extraField != null)
						{
							%>
							<tr <%=valueIfNotNull("class=\"", extraField.getClazz(), "\"")%> id="extra-row">
								<th class="bg-filled-100"><%=extraField.getPrompt() %></th>
								<td><input class="text" name="extraField" id="extraField"
									type="<%=extraField.hasHiddenCharacters() ? "password" : "text"%>"
									<%=denyLogin ? "disabled" : ""%>
									<%=valueIfNotNull("style=\"", extraField.getStyle(), "\"") %>
									<%=valueIfNotNull("title=\"", extraField.getTooltip(), "\"") %>
									<%=valueIfNotNull("placeholder=\"", extraField.getPlaceHolder(), "\"") %>
									maxlength="80"
									tabindex="3">
								</td>
							</tr>
							<%
						}
						%>
						<tr>
							<th class="bg-filled-100 subprompt"></th>
							<td colspan="2">
							<%
							String forgotPassword = sc.getClientDefaultSetting("server.forgotten.password");
							String getAccount = sc.getClientDefaultSetting("server.get.account");
							if (forgotPassword != null)
							{
								%>
								<base:icon id="forgotPassword" image="bullet.png" 
									tooltip="Click here if you have forgotten your password">Forgot your password?</base:icon>
								<%
							}
							if (getAccount != null)
							{
								%>
								<base:icon id="getAccount" image="bullet.png" 
									tooltip="Click here if you want to get an account on this server">Get an account!</base:icon>
								<%
							}
							%>
							</td>
						</tr>
						</table>
					</div>
				</td>
			</tr>
			</table>
			<%
			if (denyLogin)
			{
				%>
				<div class="messagecontainer help" id="denyLogin">
					<b><%=HTML.encodeTags(broadcastTitle) %> (login disabled)</b><br>
					<%=HTML.niceFormat(broadcastMessage)%>
					<base:buttongroup style="margin-top: 1em;">
						<base:button id="btnLoginAnyway" title="Login anyway" image="login.png" tooltip="At your own risk!" />
					</base:buttongroup>
				</div>
				<%
			}
			if (!again)
			{
				String aboutServer = sc.getClientDefaultSetting("server.about");
				if (aboutServer != null)
				{
					%>
					<h3 style="margin-top: 1em;">About this server</h3>
					<p>
						<%=aboutServer%>
					</p>
					<base:icon id="aboutServer" image="bullet.png">More about this server</base:icon>
					<%
				}
				%>
				<h3 style="margin-top: 1em;">News and announcements 
				<%
				if (RssNewsFeed.isEnabled()) 
				{
					%>
					<a href="info/news.rss" 
						title="Subscribe to news from this BASE server"
						><base:icon image="rss.png" style="float: right;" /></a>
					<%
				}
				%>
				</h3>
				<div id="news" class="news">
				<%
				if (broadcastTitle != null)
				{
					%>
					<div class="item note sticky">
						<div class="headline">
							<span class="date"><%=dateFormatter.format(new Date())%></span>
							<%=HTML.encodeTags(broadcastTitle)%><%=denyLogin ? " (login disabled)" : "" %>
						</div>
						<div class="text"><%=HTML.niceFormat(broadcastMessage)%></div>
					</div>
					<% 
				}
				
				ItemQuery<News> query = News.getQuery();
				query.order(Orders.desc(Hql.property("sticky")));
				query.order(Orders.desc(Hql.property("newsDate")));
				query.order(Orders.desc(Hql.property("id")));
				query.setCacheResult(true);
				query.setReturnTotalCount(true);
				news = query.iterate(dc);
				int numListed = 0;
				while (news.hasNext())
				{
					News n = news.next();
					if (numListed >= 10 && !n.isSticky()) break;
					%>
					<div class="item <%=n.isSticky() ? "note sticky" : ""%>">
						<div class="headline">
							<span class="date"><%=dateFormatter.format(n.getNewsDate())%></span>
							<%=HTML.encodeTags(n.getName())%>
						</div>
						<div class="text"><%=HTML.niceFormat(n.getDescription())%></div>
					</div>
					<%
					numListed++;
				}
				if (numListed < news.getTotalCount())
				{
					%>
					<base:icon image="bullet.png" /><a href="info/news.jsp" 
						title="Show older news..."><%=news.getTotalCount()-numListed%> more</a>
					<%
				}
				%>
				</div>
				<%
			}
			%>
		</td>
		</tr>
		</table>

		</form>
	</base:body>
	</base:page>
	<%
}
finally
{
	if (dc != null) dc.close();
}
%>

