/* $Id $
	------------------------------------------------------------------
	Copyright (C) 2013 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
*/
'use strict';

var BioAssaySets = function()
{
	var bioassaysets = {};
	var plotQueue;
	var plotIndex;
	
	/**
		Initialize the page.
	*/
	bioassaysets.initPage = function()
	{
		var pageId = Doc.getPageId();
		if (pageId == 'edit-page')
		{
			// Save + Close buttons
			Buttons.addClickHandler('btnSave', bioassaysets.save);
			Buttons.addClickHandler('close', App.closeWindow);

			// Tab validation
			TabControl.addTabActivateListener('settings.annotations', Annotations.onSwitchToAnnotationsTab);
			TabControl.addTabValidator('settings.info', bioassaysets.validateBioAssaySet);
		}
		else if (pageId == 'view-page')
		{
			var itemId = Data.get('page-data', 'item-id');
			var experimentId = Data.get('page-data', 'experiment-id');
			var attributes = {'item-type': 'BIOASSAYSET', 'item-id': itemId, 'extra-url': '&experiment_id='+experimentId};

			Buttons.addClickHandler('btnEdit', Buttons.editItem, attributes);
			Buttons.addClickHandler('btnDelete', Buttons.deleteItem, attributes);
			Buttons.addClickHandler('btnRestore', Buttons.restoreItem, attributes);
			Buttons.addClickHandler('btnDeletePermanently', Buttons.deleteItemPermanently, attributes);
			Buttons.addClickHandler('btnExport', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnImport', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnRunPlugin', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnFilter', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnAnalyze', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnPlot', bioassaysets.openPlotTool);
			Buttons.addClickHandler('btnExperimentExplorer', bioassaysets.openExperimentExplorer);

			TabControl.addTabActivateListener('view.annotations', AnnotationsList.loadOnce);
			TabControl.addTabActivateListener('view.bioassays', bioassaysets.viewBioAssays);
			TabControl.addTabActivateListener('view.spotdata', bioassaysets.viewSpotData);
			if (Data.get('view', 'initial-tab') != 'overviewplots')
			{
				TabControl.addTabActivateListener('view.overviewplots', bioassaysets.viewOverviewPlots);
			}
			else
			{
				TabControl.setSwitchFunction('overviewplots', bioassaysets.loadOverviewPlots);
				Doc.addFinalizer(bioassaysets.loadOverviewPlots); // Need delay since tab is not yet active
			}
		}
		else if (pageId == 'list-page')
		{
			var attributes = {'item-type': 'BIOASSAYSET'};
			var tableAttributes = {'table-id': 'bioAssaySets'};

			Buttons.addClickHandler('close', App.closeWindow);
			Buttons.addClickHandler('btnOk', Buttons.returnSelected, tableAttributes);
			
			TabControl.setSwitchFunction('main', bioassaysets.switchTab);
		}
	}
	
	bioassaysets.switchTab = function(event)
	{
		var target = event.target;
		var tabId = target.id.substring(5);
		
		var frm = document.forms['bioAssaySets'];
		var experimentId = frm.experiment_id.value;

		var url;
		if (tabId == 'clonedreporters')
		{
			url = '../reporters/index.jsp?ID='+App.getSessionId();
			url += '&experiment_id='+experimentId;
		}
		else
		{
			url = '../index.jsp?ID='+App.getSessionId();
			url += '&cmd=ViewItem&item_id='+experimentId;
			url += '&tab='+tabId;
		}
		location.replace(url);
	}

	bioassaysets.validateBioAssaySet = function()
	{
		var frm = document.forms['bioAssaySet'];
		if (Strings.trim(frm.name.value) == '')
		{
			Forms.showNotification(frm.name, 'You must enter a name');
			return false;
		}
		return true;
	}

	bioassaysets.save = function()
	{
		var frm = document.forms['bioAssaySet'];
		if (TabControl.validateActiveTab('settings'))
		{
			Annotations.saveModifiedAnnotationsToForm(frm);
			frm.submit();
		}
	}
	
	bioassaysets.viewBioAssays = function()
	{
		var url = '../bioassays/index.jsp?ID='+App.getSessionId();
		url += '&experiment_id='+Data.get('page-data', 'experiment-id');
		url += '&bioassayset_id='+Data.get('page-data', 'item-id');
		location.replace(url);
	}
	
	bioassaysets.viewSpotData = function()
	{
		var url = '../spotdata/index.jsp?ID='+App.getSessionId();
		url += '&experiment_id='+Data.get('page-data', 'experiment-id');
		url += '&bioassayset_id='+Data.get('page-data', 'item-id');
		location.replace(url);
	}

	bioassaysets.viewOverviewPlots = function()
	{
		var url = 'index.jsp?ID='+App.getSessionId();
		url += '&cmd=ViewItem&tab=overviewplots';
		url += '&experiment_id='+Data.get('page-data', 'experiment-id');
		url += '&bioassayset_id='+Data.get('page-data', 'item-id');
		location.replace(url);
	}
	
	bioassaysets.openPlotTool = function()
	{
		var url = '../plotter/index.jsp?ID='+App.getSessionId();
		url += '&bioassayset_id='+Data.get('page-data', 'item-id');
		Dialogs.openPopup(url, 'Plotter', 1250, 700);
	}
	
	bioassaysets.openExperimentExplorer = function(event)
	{
		var url = '../explorer/view/index.jsp?ID='+App.getSessionId();
		url += '&bioassayset_id='+Data.get('page-data', 'item-id');
		location.href = url;
	}

	/*
		Initialize loading of overview plots for a single tab.
		Eg. load 'plot' elements into the 'plotQueue' and reset
		the plotIndex.
	*/
	bioassaysets.loadOverviewPlots = function(event)
	{
		if (event)
		{
			TabControl.setActiveTab(event.currentTarget);
		}
		var content = Doc.element(Doc.element('overviewplots').activeTab.id+'.content');
		
		plotQueue = content.getElementsByClassName('plot');
		plotIndex = 0;
		setTimeout(bioassaysets.loadNextPlot, 100);
	}
	
	/*
		Start loading the next plot from the plotQueue. plotIndex points
		to the next plot to be loaded.
	*/
	bioassaysets.loadNextPlot = function()
	{
		if (!plotQueue) return;

		// Find next plot that is not yet loaded
		while (plotIndex < plotQueue.length && Data.int(plotQueue[plotIndex], 'is-loaded'))
		{
			plotIndex++;
		}
		if (plotIndex >= plotQueue.length) return;
		
		// Start loading the next plot in a temporary image
		// while displaying a progress bar in the real image
		// An event is used to catch the loading of the plot
		var plot = plotQueue[plotIndex];
		plot.src = '../../../images/plot_generating_400x300.gif';
		var tmpPlot = new Image();
		Events.addEventHandler(tmpPlot, 'load', bioassaysets.plotLoaded);
		tmpPlot.src = Data.get(plot, 'plot-url');
		
	}
	
	/*
	 	Event handler that is called when a plot has been loaded.
	 	Copy the plot to the real image and schedule loading of the
	 	plot.
	 */
	bioassaysets.plotLoaded = function(event)
	{
		var tmpPlot = event.currentTarget;
		var plot = plotQueue[plotIndex];
		
		plot.src = tmpPlot.src;
		Data.set(plot, 'is-loaded', 1);
		Doc.removeClass(plot, 'empty');
		
		plotIndex++;
		if (plotIndex < plotQueue.length)
		{
			setTimeout(bioassaysets.loadNextPlot, 100);
		}
	}
	
	return bioassaysets;
}();

Doc.onLoad(BioAssaySets.initPage);
